@@ -203,7 +203,7 @@ CollectionDB::isValid(const QString &column, const QString &table)
 
 
 void
-CollectionDB::createTables( DbConnection *conn )
+CollectionDB::createTables( DbConnection */*conn*/ )
 {
 
     //create tag table
@@ -233,7 +233,7 @@ CollectionDB::createMetaDBTable( DbConnection *conn )
 }
 
 void
-CollectionDB::loadMetaDBTable(  DbConnection *conn  )
+CollectionDB::loadMetaDBTable(  DbConnection */*conn*/  )
 {
 
 	QString location = locate("data", "klamav/about/metadb.txt");
