@@ -23,10 +23,11 @@
 
 #include <kprocess.h>
 #include <ktempfile.h>
+#include <stdlib.h>      // system
 
 using namespace std;
 
-CTCron::CTCron(bool _syscron, string _login) :
+CTCron::CTCron(bool _syscron, string ) :
   syscron(_syscron)
 {
   int uid(getuid());
