@@ -27,7 +27,7 @@ using namespace std;
 
 CTHost::CTHost()
 {
-  struct passwd *pwd = 0L;
+//  struct passwd *pwd = 0L;
 
   // If it is the root user
 /*  if (getuid() == 0)
