@@ -12,6 +12,7 @@
 #include "pageviewer.h"
 #include "tabwidget.h"
 #include "freshklam.h"
+#include "../config.h"
 
 #include <qheader.h>
 #include <qlayout.h>
@@ -80,8 +81,6 @@ KlamDB::KlamDB( QWidget* parent, const char* name, bool modal, WFlags fl )
 
     VirusList = new KListView( privateLayoutWidget, "VirusList" );
     VirusList->addColumn( i18n( "All Known Viruses" ),150 );
-/*    VirusList->setResizeMode(QListView::AllColumns);
-    VirusList->setColumnWidthMode(0,QListView::Maximum);*/
     connect(VirusList, SIGNAL( doubleClicked( QListViewItem * , const QPoint &, int ) ),
                     this, SLOT(slotOpenTab(QListViewItem * , const QPoint &, int )) );
 
@@ -91,32 +90,32 @@ KlamDB::KlamDB( QWidget* parent, const char* name, bool modal, WFlags fl )
     QPixmap vicon;
     QPixmap ticon;
 
-        QString iconPath = locate("cache", KMimeType::favIconForURL("http://www.viruspool.net")+".png");
-        if ( iconPath.isEmpty() )
-          vicon = SmallIcon("find");
-        else
-          vicon = QPixmap( iconPath );
+    QString iconPath = locate("cache", KMimeType::favIconForURL("http://www.viruspool.net")+".png");
+    if ( iconPath.isEmpty() )
+      vicon = SmallIcon("find");
+    else
+      vicon = QPixmap( iconPath );
 
-        iconPath = locate("cache", KMimeType::favIconForURL("http://www.google.com")+".png");
-        if ( iconPath.isEmpty() )
-          gicon = SmallIcon("find");
-        else
-          gicon = QPixmap( iconPath );
+    iconPath = locate("cache", KMimeType::favIconForURL("http://www.google.com")+".png");
+    if ( iconPath.isEmpty() )
+      gicon = SmallIcon("find");
+    else
+      gicon = QPixmap( iconPath );
 
-        iconPath = locate("cache", KMimeType::favIconForURL("http://www.trendmicro.com")+".png");
-        if ( iconPath.isEmpty() )
-          ticon = SmallIcon("find");
-        else
-          ticon = QPixmap( iconPath );
+    iconPath = locate("cache", KMimeType::favIconForURL("http://www.trendmicro.com")+".png");
+    if ( iconPath.isEmpty() )
+      ticon = SmallIcon("find");
+    else
+      ticon = QPixmap( iconPath );
 
-        menu->insertItem(vicon, i18n("Search in VirusList"), this,SLOT(slotVirusList()) );
-        menu->insertItem(vicon, i18n("Search in VirusPool"), this,SLOT(slotVirusPool()) );
-        menu->insertItem(ticon, i18n("Search with Trend Micro"), this,SLOT(slotTrendMicro()) );
-        menu->insertItem(gicon, i18n("Search with Google"), this,SLOT(slotGoogle()) );
+    menu->insertItem(vicon, i18n("Search in VirusList"), this,SLOT(slotVirusList()) );
+    menu->insertItem(vicon, i18n("Search in VirusPool"), this,SLOT(slotVirusPool()) );
+    menu->insertItem(ticon, i18n("Search with Trend Micro"), this,SLOT(slotTrendMicro()) );
+    menu->insertItem(gicon, i18n("Search with Google"), this,SLOT(slotGoogle()) );
+
+    connect(VirusList, SIGNAL( contextMenuRequested( QListViewItem *, const QPoint& , int ) ), 
+    this, SLOT( slotRMB( QListViewItem *, const QPoint &, int ) ) );
 
-        connect(VirusList, SIGNAL( contextMenuRequested( QListViewItem *, const QPoint& , int ) ), 
-        this, SLOT( slotRMB( QListViewItem *, const QPoint &, int ) ) );
-    
     kLineEdit1 = new KListViewSearchLine( (QWidget *)searchToolBar, VirusList,"klinedit1");
     QValueList<int> columns;
         columns.append(0);
@@ -131,10 +130,8 @@ KlamDB::KlamDB( QWidget* parent, const char* name, bool modal, WFlags fl )
     
 
     languageChange();
-    //resize( QSize(600, 480).expandedTo(minimumSizeHint()) );
     clearWState( WState_Polished );
     
-    //listdir((const char *)QString("/home/robert/.klamav/database"));
     slotOpenHome();
 }
 
@@ -169,6 +166,14 @@ int KlamDB::listdb(const char *filename)
     int line = 0, bytes;
     const char *tmpdir;
 
+    if(cli_strbcasestr(filename, ".inc")) { /* incremental directory */
+	if(listdir(filename) == -1) {
+	    printf("!listdb: Can't list incremental directory %s\n", filename);
+	    return -1;
+	}
+	return 0;
+    }
+
     if((fd = fopen(filename, "rb")) == NULL) {
     printf("!listdb(): Can't open file %s\n", filename);
     return -1;
@@ -202,15 +207,6 @@ int KlamDB::listdb(const char *filename)
         delete tf;
         return -1;
     }
-    //dir = tf.name();
-    
-    //kdDebug() << tf->name() << endl;
-//     if(mkdir(tf->name(), 0700)) {
-//         printf("!listdb(): Can't create temporary directory \n");
-//         free(buffer);
-//         fclose(fd);
-//         return -1;
-//     }
 
     /* FIXME: it seems there is some problem with current position indicator
     * after gzdopen() call in cli_untgz(). Temporarily we need this wrapper:
@@ -218,12 +214,7 @@ int KlamDB::listdb(const char *filename)
 
     /* start */
 
-/*    tmp = cli_gentemp(tmpdir);*/
     KTempFile* tn = new KTempFile(tf->name());
-    //tn->close();
-    //tn->unlink();
-
-    //kdDebug() << tn->name() << endl;
     
     if((tmpd = fopen(tn->name(), "wb+")) == NULL) {
         printf("!listdb(): Can't create temporary file \n");
@@ -359,11 +350,15 @@ int KlamDB::listdir(const char *dirname)
 #endif
     {
         if(strcmp(dent->d_name, ".") && strcmp(dent->d_name, "..") &&
-        (cli_strbcasestr(dent->d_name, ".db")  ||
-         cli_strbcasestr(dent->d_name, ".db2") ||
-         cli_strbcasestr(dent->d_name, ".hdb") ||
-         cli_strbcasestr(dent->d_name, ".ndb") ||
-         cli_strbcasestr(dent->d_name, ".cvd"))) {
+	    (cli_strbcasestr(dent->d_name, ".db")  ||
+	     cli_strbcasestr(dent->d_name, ".hdb") ||
+	     cli_strbcasestr(dent->d_name, ".mdb") ||
+	     cli_strbcasestr(dent->d_name, ".ndb") ||
+	     cli_strbcasestr(dent->d_name, ".sdb") ||
+	     cli_strbcasestr(dent->d_name, ".zmd") ||
+	     cli_strbcasestr(dent->d_name, ".rmd") ||
+	     cli_strbcasestr(dent->d_name, ".inc") ||
+	     cli_strbcasestr(dent->d_name, ".cvd"))) {
 
         dbfile = (char *) calloc(strlen(dent->d_name) + strlen(dirname) + 2, sizeof(char));
 
@@ -407,11 +402,15 @@ int KlamDB::checkdir(const char *dirname)
 #endif
     {
         if(strcmp(dent->d_name, ".") && strcmp(dent->d_name, "..") &&
-        (cli_strbcasestr(dent->d_name, ".db")  ||
-         cli_strbcasestr(dent->d_name, ".db2") ||
-         cli_strbcasestr(dent->d_name, ".hdb") ||
-         cli_strbcasestr(dent->d_name, ".ndb") ||
-         cli_strbcasestr(dent->d_name, ".cvd"))) {
+	    (cli_strbcasestr(dent->d_name, ".db")  ||
+	     cli_strbcasestr(dent->d_name, ".hdb") ||
+	     cli_strbcasestr(dent->d_name, ".mdb") ||
+	     cli_strbcasestr(dent->d_name, ".ndb") ||
+	     cli_strbcasestr(dent->d_name, ".sdb") ||
+	     cli_strbcasestr(dent->d_name, ".zmd") ||
+	     cli_strbcasestr(dent->d_name, ".rmd") ||
+	     cli_strbcasestr(dent->d_name, ".inc") ||
+	     cli_strbcasestr(dent->d_name, ".cvd"))) {
         found = 1;
         }
     }
@@ -788,7 +787,7 @@ unsigned int  KlamDB::getSigNos()
         
     unsigned int ret= 0;
     unsigned int no = 0;
-    struct cl_node *root = NULL;
+    struct cl_engine *engine = NULL;
     QStringList lastDownloadPaths;
     QString dbdir;
     QString db;
@@ -798,10 +797,22 @@ unsigned int  KlamDB::getSigNos()
     lastDownloadPaths = config->readListEntry("lastDownloadPaths");
     dbdir = lastDownloadPaths.first();
 
+#ifdef SUPPORT_CLAMAV_V095
+      if((engine = cl_engine_new()) == NULL) {
+          printf("Database initialization error: %s\n", cl_strerror(ret));;
+          cl_engine_free(engine);
+          return 0;
+      }
+#endif
 
-    ret = cl_loaddbdir((const char *)dbdir, &root, &no);
-    //kdDebug() << "no " << no << endl;
-    cl_free(root);
+#ifdef SUPPORT_CLAMAV_V095
+    ret = cl_load((const char *)dbdir, engine, &no, CL_DB_STDOPT);
+    cl_engine_free(engine);
+#else
+    ret = cl_load((const char *)dbdir, &engine, &no, CL_DB_STDOPT);
+    cl_free(engine);
+#endif
+    kdDebug() << "no of sigs" << no << endl;
     return no;
 
 }
