@@ -290,7 +290,7 @@ DeviceItem::DeviceItem( QListViewItem *parent, const QString &name, const KURL &
     
     setText(1, KURL(retVal[6]).path());
 	setText(2, url.fileName());
-    //kdDebug() << "Device Item: " << name << " " << url.fileName() << " " << text(1) << endl;
+    kdDebug() << "Device Item: " << name << " " << url.fileName() << " " << text(1) << endl;
     m_lister.setDirOnlyMode( true );
     setExpandable( false );
     connect( &m_lister, SIGNAL(newItems( const KFileItemList& )), SLOT(newItems( const KFileItemList& )) );
@@ -372,7 +372,7 @@ DeviceItem::newItems( const KFileItemList &list ) //SLOT
 {
     for( KFileItemListIterator it( list ); *it; ++it )
     {
-        ////kdDebug() << (*it)->name() << " " << (*it)->url() << " " << (*it)->text() << endl;
+        kdDebug() << (*it)->name() << " " << (*it)->url() << " " << (*it)->text() << endl;
         if (this->listView()->findItem((*it)->name(),0) == 0){
             DeviceItem *item = new DeviceItem( this, (*it)->name(), (*it)->url() );
 
