@@ -9,6 +9,8 @@
 #include "collectiondb.h"
 /*#include "gmanedb.h"*/
 #include "klamavconfig.h"
+#include "config.h"
+#include "../config.h"
 
 #include <klocale.h>
 #include <kio/netaccess.h>
@@ -151,11 +153,12 @@ Freshklam::Freshklam(QWidget *parent, const char *name)
     connect( klamav_options, SIGNAL( clicked() ), this,
 		SLOT( checkForNewKlamAVNow() ) );
 
-
-
-
-
-
+#ifdef DISABLE_UPDATES
+    clamav_box->setEnabled(false);
+    klamav_box->setEnabled(false);
+    clamav_options->setEnabled(false);
+    klamav_options->setEnabled(false);
+#endif
     //Virus Database Directory
     QGroupBox *group = new QGroupBox(i18n("Virus Database Directory"), this);
     vbox->addWidget(group);
@@ -356,6 +359,7 @@ void Freshklam::processOutput()
 
     if ((pos = item2.find("Recommended version:")) != -1){
 
+    	kmain->_tray->setPixmap(KSystemTray::loadIcon("klamav_update_required"));
         pos2 = item2.find('\n',pos);
         QString version = item2.mid((pos+20),pos2 - (pos+20)).stripWhiteSpace();
 
@@ -445,10 +449,10 @@ void Freshklam::slotSearch()
     connect( childproc, SIGNAL(receivedStdout(KProcess *, char *, int)),
         SLOT(receivedOutput(KProcess *, char *, int)) );
     
-    if (kmain->klamd->isKlamdAlive())
-        kmain->_tray->setPixmap(KSystemTray::loadIcon("klamavdl"));    
-    else
-        kmain->_tray->setPixmap(KSystemTray::loadIcon("klamavbwdl"));    
+//     if (kmain->klamd->isKlamdAlive())
+//         kmain->_tray->setPixmap(KSystemTray::loadIcon("klamavdl"));    
+//     else
+//         kmain->_tray->setPixmap(KSystemTray::loadIcon("klamavbwdl"));    
 
     kmain->EnableFreshklam->setEnabled(FALSE);
     kmain->DisableFreshklam->setEnabled(TRUE);
@@ -462,9 +466,9 @@ void Freshklam::finish()
 
     enableInputs();
     if (kmain->klamd->isKlamdAlive())
-        kmain->_tray->setPixmap(KSystemTray::loadIcon("klamav"));    
+        kmain->_tray->setPixmap(KSystemTray::loadIcon("klamav_on_acc_enabled"));    
     else
-        kmain->_tray->setPixmap(KSystemTray::loadIcon("klamavbw"));    
+        kmain->_tray->setPixmap(KSystemTray::loadIcon("klamav_on_acc_disabled"));
 
     buf += '\n';
     processOutput();
@@ -692,7 +696,7 @@ void Freshklam::writeConf()
 
     ts << "DatabaseMirror database.clamav.net" << "\n";
     ts << "DNSDatabaseInfo current.cvd.clamav.net" << "\n";
-    ts << "Foreground" << "\n";
+    ts << "Foreground True" << "\n";
     if ( (proxyIP->hasAcceptableInput()) && (!(proxyIP->text().isEmpty()))) {
         ts << QString("HTTPProxyServer %1").arg(proxyIP->text()) << "\n";
         if ( proxyPort->hasAcceptableInput() ) {
@@ -819,9 +823,9 @@ void  Freshklam::enableInputs(){
 }
 
 QString  Freshklam::getCurrentDBDir(){
-        unsigned int ret= 0;
+    unsigned int ret= 0;
     unsigned int no = 0;
-        struct cl_node *root = NULL;
+    struct cl_engine *engine = NULL;
     QStringList lastDownloadPaths;
     QString dbdir;
     QString db;
@@ -835,7 +839,13 @@ QString  Freshklam::getCurrentDBDir(){
     
 
     if (dbdir != dir_combo->url()){
-        ret = cl_loaddbdir((const char *)dir_combo->url(), &root, &no);
+        /* load all available databases from default directory */
+#ifdef SUPPORT_CLAMAV_V095
+        ret = cl_load((const char *)dir_combo->url(), engine, &no, CL_DB_STDOPT);
+#else
+        ret = cl_load((const char *)dir_combo->url(), &engine, &no, CL_DB_STDOPT);
+#endif
+        //ret = cl_loaddbdir((const char *)dir_combo->url(), &root, &no);
         ////kdDebug() << "ret " << ret << endl;
         if (no == 0){
             db = dbdir;
@@ -1008,6 +1018,7 @@ void Freshklam::readVersionLine(KProcIO *)
 			QString currentClamAVVersion = lineout.mid(StartPoint,(EndPoint - StartPoint));
                         currentClamAVVersion = currentClamAVVersion.stripWhiteSpace();
 			KlamavConfig::setClamAVVersion(currentClamAVVersion);
+            KlamavConfig::writeConfig();
                         ////kdDebug() << currentClamAVVersion << endl;
 		}
    	}
