@@ -8,6 +8,7 @@
 #include "directorylist.h"
 #include "dbviewer.h"
 #include "collectiondb.h"
+#include "klamd.h"
 
 #include <config.h>
 #include "klamavconfig.h"
@@ -181,6 +182,7 @@ void ScanViewer::processOutput()
 
     //buf.replace("//","/"); // don't know why they're getting two slashes
     while ((childproc) && ((pos = (childproc->readln(item2,true))) != -1)) {
+            QListViewItem* tm;
             //item2 = (buf.section('\n',j,j)).stripWhiteSpace();
             item2 = item2.stripWhiteSpace();
             int fnameStartPoint = 0;
@@ -198,8 +200,8 @@ void ScanViewer::processOutput()
 
                 if ((tmpVirusName.find("FOUND")) != -1){
                     tmpVirusName.replace("FOUND","");
-                    QListViewItem* tm = new QListViewItem( resultview, tmpFName, tmpVirusName.stripWhiteSpace(),"Loose");
-                    tm->setPixmap( 0, SmallIcon("klamav") );
+                    tm = new QListViewItem( resultview, tmpFName, tmpVirusName.stripWhiteSpace(),"Loose");
+                    tm->setPixmap( 0, SmallIcon("klamav_virus") );
                     //resultview->insertItem(buf.section('\n',j,j));
                     QuarantineList.append(tmpFName+":"+tmpVirusName+suffix);
                 CollectionDB::instance()->insertEvent("Virus Found",tmpVirusName,tmpFName);
@@ -212,7 +214,8 @@ void ScanViewer::processOutput()
             //}else if ((pos = buf.section('\n',j,j).find("ERROR:")) != -1){
             }else if ((pos = (item2.find("ERROR:"))) != -1){
                 QString tmpVirusName = item2.mid((fnameEndPoint+1),(item2.length() - (fnameEndPoint+1)));
-                new QListViewItem( resultview, tmpFName, tmpVirusName.stripWhiteSpace(),"Not a Virus");
+                tm = new QListViewItem( resultview, tmpFName, tmpVirusName.stripWhiteSpace(),"Not a Virus");
+                tm->setPixmap( 0, SmallIcon("klamav_error") );
                 //resultview->insertItem(buf.section('\n',j,j));
                 CollectionDB::instance()->insertEvent("Error Found",tmpVirusName,tmpFName);
 
@@ -589,6 +592,13 @@ void ScanViewer::slotCancel()
 
 }
 
+void ScanViewer::resetSysTray()
+{
+    if (kmain->klamd->isKlamdAlive())
+      kmain->_tray->setPixmap(KSystemTray::loadIcon("klamav_on_acc_enabled"));
+    else
+      kmain->_tray->setPixmap(KSystemTray::loadIcon("klamav_on_acc_disabled"));
+}
 
 void ScanViewer::childExited()
 {
@@ -600,12 +610,15 @@ void ScanViewer::childExited()
     CollectionDB::instance()->insertEvent("Manual Scan",QString("Scan Complete"),m_filepattern.join(" "));
 
     if (status == 0){
+    	kmain->_tray->setPixmap(KSystemTray::loadIcon("klamav_scan_safe"));
+        QTimer::singleShot( 10000, this, SLOT(resetSysTray()) );
         if (!(errorsEncountered))
             KNotifyClient::event(kmain->_tray->winId(),i18n( "ScanCompleteNoVirus" ), i18n( "Scan Complete - No Viruses Found!" ));
         else
             KNotifyClient::event(kmain->_tray->winId(),i18n( "ScanCompleteNoVirusButErrors" ), i18n( "Scan Complete - No Viruses Found But Some Errors Encountered!" ));
 
     }else if(status == 1){
+    	kmain->_tray->setPixmap(KSystemTray::loadIcon("klamav_scan_found"));
         switch (m_mode) {
         case 0:
             progosd->setText("Problems found!");
@@ -692,60 +705,41 @@ void ScanViewer::slotClear()
 // }
 
 void  ScanViewer::Quarantine(){
-    
-    //config = KGlobal::config();
+    bool allQuarantined=TRUE;
     config->setGroup("Kuarantine");
-    //lastQuarItems = config->readListEntry("KuarantineItems");
     QStringList lastQuarLocations = config->readListEntry("KuarantineLocations");
-    
+
+    kmain->_tray->setPixmap(KSystemTray::loadIcon("klamav_quarantining"));
+
     QString quarloc;
     for (QStringList::Iterator it = lastQuarLocations.begin(); it == lastQuarLocations.begin() ; it++){
             quarloc = *it;
     }
-        
-    //Get Items for this location
-    
     lastQuarItems = config->readListEntry(QString("Items %1").arg(quarloc));
-    
-    
+
     for (QStringList::Iterator it = QuarantineList.begin(); it != QuarantineList.end(); it++ ){
         if (lastQuarItems.contains(*it) != 0) {
             lastQuarItems.remove(*it);
         }
         QString item2 = (*it).stripWhiteSpace();
-        ////kdDebug() << item2 << endl;
         int fnameStartPoint = 0;
         int dtStartPoint = item2.findRev(":");
         int fnameEndPoint = item2.findRev(":", (signed int)-((item2.length() - dtStartPoint)+1));
-        ////kdDebug() << QString("%1").arg((signed int)-((item2.length() - dtStartPoint)+1)) << endl;
-        ////kdDebug() << QString("%1").arg(dtStartPoint) << endl;
-        ////kdDebug() << QString("%1").arg(fnameEndPoint) << endl;
         QString fname = item2.mid(fnameStartPoint,(fnameEndPoint - fnameStartPoint));
         QString itemName = item2.mid((fnameEndPoint+1),((dtStartPoint+1) - (fnameEndPoint+2)));
         QString when = item2.mid((dtStartPoint+1),(item2.length() - (dtStartPoint+1)));
-        ////kdDebug() << fname << endl;
-        ////kdDebug() << itemName << endl;
-        ////kdDebug() << when << endl;
         if (!(fname.isEmpty())){
             QStringList tokens = QStringList::split ( "/", fname, FALSE );
             QString qname = tokens.last();
             qname.prepend("/");
             qname.prepend(quarloc);
             qname.append(":"+when);
-            /*
-            QString suCommand=QString("mv -f '%1' '%2'").arg(fname).arg(qname);
-            KProcIO *proc = new KProcIO();
-            proc->setUseShell(TRUE);
-            *proc<<suCommand;
-            
-            proc->start(KProcIO::NotifyOnExit);
-            */
             if (KIO::NetAccess::file_move(fname,qname)){
                 if (lastQuarItems.contains(item2))
                     lastQuarItems.remove(item2);
                 lastQuarItems.prepend(item2);
                 (resultview->findItem(fname,0))->setText(2,"Quarantined");
-                    (resultview->findItem(fname,0))->setPixmap( 0, SmallIcon("klamavbw") );
+                (resultview->findItem(fname,0))->setPixmap( 0, SmallIcon("klamav") );
                 chmod((const char *)qname,0400);
                 CollectionDB::instance()->insertEvent("Quarantine",QString("Quarantined"),fname);
 
@@ -756,6 +750,13 @@ void  ScanViewer::Quarantine(){
             
         }
     }
+    if (allQuarantined) {
+      if (kmain->klamd->isKlamdAlive())
+        kmain->_tray->setPixmap(KSystemTray::loadIcon("klamav_on_acc_enabled"));
+      else
+        kmain->_tray->setPixmap(KSystemTray::loadIcon("klamav_on_acc_disabled"));
+    }else
+        kmain->_tray->setPixmap(KSystemTray::loadIcon("klamav_scan_found"));
     config->writeEntry(QString("Items %1").arg(quarloc), lastQuarItems);
     config->sync();
     
@@ -813,21 +814,21 @@ void ScanViewer::slotRMB( QListViewItem* Item, const QPoint & point, int )
 void ScanViewer::slotQuarantineSelected()
 {
 
-           QPtrList<QListViewItem> list;
+    QPtrList<QListViewItem> list;
     QListViewItemIterator it( resultview, QListViewItemIterator::Selected );
     
     QuarantineList = "";
-        while ( it.current() ) {
-        QListViewItem* tItem = it.current();
-        
-        QDate today = QDate::currentDate();
-        QTime now = QTime::currentTime();
-        QString suffix = QString(":%1 %2")
-            .arg(today.toString("ddd MMMM d yyyy"))
-            .arg(now.toString("hh-mm-ss ap"));
+    while ( it.current() ) {
+      QListViewItem* tItem = it.current();
 
-        QuarantineList.append(tItem->text(0)+":"+tItem->text(1)+suffix);
-        ++it;
+      QDate today = QDate::currentDate();
+      QTime now = QTime::currentTime();
+      QString suffix = QString(":%1 %2")
+          .arg(today.toString("ddd MMMM d yyyy"))
+          .arg(now.toString("hh-mm-ss ap"));
+
+      QuarantineList.append(tItem->text(0)+":"+tItem->text(1)+suffix);
+      ++it;
     }
 
     Quarantine();
