@@ -29,7 +29,7 @@ Schedule::Schedule( QWidget* parent, QStringList filepattern, const char* name,
 	setCaption( i18n( "Schedule Scan" ) );
 
  	cthost = new CTHost();
- 	const CTHost& cth(*cthost);
+// 	const CTHost& cth(*cthost);
 
 	// for each user
 //  	CTCronIterator i = const_cast<CTHost&>(cth).cron.begin();
@@ -146,7 +146,7 @@ Schedule::~Schedule()
 }
 
 
-void Schedule::slotQueryDatePicker(int index)
+void Schedule::slotQueryDatePicker(int)
 {
 
 	if (check_combo->currentText().contains(i18n("specific date")) ){
@@ -365,7 +365,7 @@ QString Schedule::createScanScript()
 		ts << "export HOSTNAME" << "\n";
 		ts << QString("PATH=%1").arg(QString(getenv("PATH"))) << "\n";
 		ts << "export PATH" << "\n";
-		ts << "DCOPSERVER=`cat /home/$USER/.DCOPserver_$HOSTNAME_:0 | grep local`" << "\n";
+		ts << "DCOPSERVER=`cat /home/${USER}/.DCOPserver_${HOSTNAME}_:0 | grep local`" << "\n";
 		ts << "export DCOPSERVER" << "\n";
 		ts << "DISPLAY=:0" << "\n";
 		ts << "export DISPLAY" << "\n";
@@ -375,19 +375,21 @@ QString Schedule::createScanScript()
 		ts << "fi" << "\n";
 		ts << "until [ -z \"$1\" ]  # Until all parameters used up..." << "\n";
 		ts << "do" << "\n";
-		ts << "  if [ \"$URL\" = \"\" ]; then" << "\n";
+		ts << "  if [ \"${URL}\" = \"\" ]; then" << "\n";
 		ts << "        URL=$1" << "\n";
 		ts << "        SCANTHIS=$1" << "\n";
 		ts << "  else" << "\n";
-		ts << "        URL=$URL'*'$1" << "\n";
-		ts << "        SCANTHIS=$SCANTHIS' '$1" << "\n";
+		ts << "        URL=${URL}'*'$1" << "\n";
+		ts << "        SCANTHIS=${SCANTHIS}' '$1" << "\n";
 		ts << "  fi" << "\n";
 		ts << "  shift" << "\n";
 		ts << "done" << "\n";
-		ts << QString("if %1/bin/dcop `%2/bin/dcop|grep klamav|head -1` DCOPKlamscan scanURLs \"$URL\"; then").arg(kdedir).arg(kdedir) << "\n";
+        ts << "DCOPEXEC=`which dcop`" << "\n";
+        ts << "KLAMAVEXEC=`which klamav`" << "\n";
+        ts << "if ${DCOPEXEC} `${DCOPEXEC}|grep klamav|head -1` DCOPKlamscan scanURLs \"${URL}\"; then" << "\n";
 		ts << "        exit 0" << "\n";
 		ts << "else" << "\n";
-		ts << QString("        %1/bin/klamav --scanthis $SCANTHIS").arg(kdedir) << "\n";
+		ts << "         ${KLAMAVEXEC} --scanthis ${SCANTHIS}" << "\n";
 		ts << "fi" << "\n";
 	
 		file.close();
