@@ -82,14 +82,18 @@ KlamavUpdate::KlamavUpdate(QWidget *parent, const char *name)
 {
 
     filelist->hide();
-
+    filelist->setJScriptEnabled(false);
+    filelist->setJavaEnabled(false);
+    filelist->setAutoloadImages(false);
+    filelist->setDNDEnabled(false);
+    filelist->setPluginsEnabled(false);
 }
 
 
 KlamavUpdate::~KlamavUpdate()
 {
     kdDebug() << "deleting" << endl;
-    delete filelist;
+    //delete filelist;
 }
 
 
@@ -146,7 +150,7 @@ void KlamavUpdate::downloadComponent(QString component, QString version, QString
             return;
         }
     
-        ////kdDebug() << "Theme is in temp file: " << tmpFile << endl;
+        kdDebug() << "Theme is in temp file: " << tmpFile << endl;
     
         if ((progressDialog) && (progressDialog->wasCancelled())){
             updateCanceled();
@@ -161,7 +165,7 @@ void KlamavUpdate::downloadComponent(QString component, QString version, QString
         KTar tar( tmpFile );
         if (!(tar.open( IO_ReadOnly ))){
             int result = KMessageBox::questionYesNo(this, i18n( "The mirror I attempted to download from has not updated yet. Should I try another?"));
-            //kdDebug() << result << endl;
+            kdDebug() << result << endl;
             switch (result) {
                 case KMessageBox::Yes : 
                     download = true; break;
@@ -238,12 +242,12 @@ void KlamavUpdate::downloadComponent(QString component, QString version, QString
 void KlamavUpdate::checkForNewKlamAV()
 {
 
-    //kdDebug() << "Checking for new KlamAV" << endl;
+    kdDebug() << "Checking for new KlamAV" << endl;
 
     checkingDirectly = false;
 
     highestsofarnumeric = 0;
-    klamav_url = "http://prdownloads.sourceforge.net/klamav/";
+    klamav_url = "http://ftp.heanet.ie/mirrors/download.sourceforge.net/pub/sourceforge/k/kl/klamav/";
     getLatestVersionFromSFHack(klamav_url);
 
 }
@@ -251,12 +255,12 @@ void KlamavUpdate::checkForNewKlamAV()
 void KlamavUpdate::checkForNewKlamAVDirectly()
 {
 
-    //kdDebug() << "Checking for new KlamAV" << endl;
+    kdDebug() << "Checking for new KlamAV" << endl;
 
     checkingDirectly = true;
 
     highestsofarnumeric = 0;
-    klamav_url = "http://prdownloads.sourceforge.net/klamav/";
+    klamav_url = "http://ftp.heanet.ie/mirrors/download.sourceforge.net/pub/sourceforge/k/kl/klamav/";
     startProgressDialog( i18n( "Checking for new version of KlamAV..." ) );
 
     getLatestVersionFromSF(klamav_url);
@@ -267,12 +271,12 @@ void KlamavUpdate::checkForNewKlamAVDirectly()
 void KlamavUpdate::checkForNewClamAVDirectly()
 {
 
-    //kdDebug() << "Checking for new ClamAV" << endl;
+    kdDebug() << "Checking for new ClamAV" << endl;
 
     checkingDirectly = true;
 
     highestsofarnumeric = 0;
-    clamav_url = "http://prdownloads.sourceforge.net/clamav/";
+    clamav_url = "http://ftp.heanet.ie/mirrors/download.sourceforge.net/pub/sourceforge/c/cl/clamav/";
 
     startProgressDialog( i18n( "Checking for new version of ClamAV..." ) );
     
@@ -289,15 +293,12 @@ void KlamavUpdate::completedSearchForUpdates(const QString &component, const QSt
         currentversion = VERSION_KLAMAV;
     else{
     	QString currentClamAVVersion = KlamavConfig::clamAVVersion();
-        if (currentClamAVVersion.mid(currentClamAVVersion.length() - 2,1) == ".")
-            currentversion = currentClamAVVersion.replace(currentClamAVVersion.length() - 2,1,"").toDouble();
-        else
-            currentversion = currentClamAVVersion.toDouble();
+        currentversion = numericizeVersion(currentClamAVVersion);
     }
 
-    ////kdDebug() << "in completed search for updates" << endl;
-    ////kdDebug() << currentversion << endl;
-    ////kdDebug() << highestsofarnumeric << endl;
+    kdDebug() << "in completed search for updates" << endl;
+    kdDebug() << currentversion << endl;
+    kdDebug() << highestsofarnumeric << endl;
 
     if (highestsofarnumeric > currentversion){
         int result = KMessageBox::warningContinueCancel(this, i18n( "It looks like your version of %1 is out of date! %2-%3 is the most recent version available. Would you like KlamAV to download and compile it for you?").arg(component).arg(component).arg(highestsofarraw),i18n( "Download and Install %1-%2" ).arg(component).arg(highestsofarraw),i18n( "Download and Install %1-%2" ).arg(component).arg(highestsofarraw));
@@ -377,8 +378,8 @@ void KlamavUpdate::klamavInstallationExited(KProcess* arkollonproc)
 void KlamavUpdate::getLatestVersionFromSF(KURL url)
 {
 
-    ////kdDebug() << "getting latest version" << endl;
-    ////kdDebug() << url << endl;
+    kdDebug() << "getting latest version" << endl;
+    kdDebug() << url << endl;
     emit toggleUpgradeButtons(false);
 
     connect( filelist, SIGNAL( completed() ), this,
@@ -394,8 +395,8 @@ void KlamavUpdate::getLatestVersionFromSF(KURL url)
 void KlamavUpdate::getLatestVersionFromSFHack(KURL url)
 {
 
-    ////kdDebug() << "getting latest version" << endl;
-    ////kdDebug() << url << endl;
+    kdDebug() << "getting latest version" << endl;
+    kdDebug() << url << endl;
     emit toggleUpgradeButtons(false);
 
     connect( filelist, SIGNAL( completed() ), this,
@@ -410,7 +411,7 @@ void KlamavUpdate::getLatestVersionFromSFHack(KURL url)
 void KlamavUpdate::updateCanceled()
 {
 
-    ////kdDebug() << "cancelled" << endl;
+    kdDebug() << "cancelled" << endl;
     filelist->closeURL();
     emit toggleUpgradeButtons(true);
 }
@@ -419,11 +420,11 @@ void KlamavUpdate::parseSFPage()
 {
 
 
-    ////kdDebug() << "parsing sf page" << endl;
+    kdDebug() << "parsing sf page" << endl;
 
 
     const DOM::HTMLCollection links = filelist->htmlDocument().links();
-    ////kdDebug() << links.length() << endl;
+    kdDebug() << links.length() << endl;
 
     if (links.length() == 0){
             KMessageBox::information (this,i18n( "Could not contact update server!" ));
@@ -444,7 +445,7 @@ void KlamavUpdate::parseSFPage()
     delete progressDialog;
     progressDialog = 0;
     
-    ////kdDebug() << highestsofarfilename << endl;
+    kdDebug() << highestsofarfilename << endl;
     if (highestsofarfilename.contains("klamav"))
         completedSearchForUpdates("KlamAV", "tar.bz2");
     else if (highestsofarfilename.contains("clamav"))
@@ -457,11 +458,11 @@ void KlamavUpdate::parseSFPageHack()
 {
 
 
-    ////kdDebug() << "parsing sf page" << endl;
+    kdDebug() << "parsing sf page" << endl;
 
 
     const DOM::HTMLCollection links = filelist->htmlDocument().links();
-    ////kdDebug() << links.length() << endl;
+    kdDebug() << links.length() << endl;
 
     if (links.length() == 0){
             return;
@@ -478,7 +479,7 @@ void KlamavUpdate::parseSFPageHack()
     //delete progressDialog;
     //progressDialog = 0;
 
-    ////kdDebug() << highestsofarfilename << endl;
+    kdDebug() << highestsofarfilename << endl;
     if (highestsofarfilename.contains("klamav"))
         completedSearchForUpdates("KlamAV", "tar.bz2");
     else if (highestsofarfilename.contains("clamav"))
@@ -500,25 +501,23 @@ void KlamavUpdate::getVersionFromLink( const DOM::Node &n )
         
         KURL href ( elem.getAttribute( "href" ).string() );
         
-        ////kdDebug() << href.filename() << endl;
+        kdDebug() << elem.getAttribute( "href" ).string() << endl;
 
-        QString name = href.filename();
+        QString name = elem.getAttribute( "href" ).string();
         QString version = name.replace(".tar.bz2","").replace(".tar.gz","");
         version = version.replace("clamav-","").replace("klamav-","");
 
-        tmpversion = version;
+        QString rawversion = version;
 
-        if ((tmpversion.mid(tmpversion.length() - 2,1) == ".") && (tmpversion.length() > 3))
-            numericversion = tmpversion.replace(tmpversion.length() - 2,1,"").toDouble();
-        else
-            numericversion = tmpversion.toDouble();
+        if (m_alpha)
+            version.remove("-alpha").remove("-beta").remove("-rc");
+
+        numericversion = numericizeVersion(version);
 
-        ////kdDebug() << version << endl;
-        ////kdDebug() << numericversion << endl;
         if (numericversion > highestsofarnumeric){
             highestsofarnumeric = numericversion;
-            highestsofarraw = version;
-            highestsofarfilename = href.filename();
+            highestsofarraw = rawversion;
+            highestsofarfilename = elem.getAttribute( "href" ).string();
         }
 
 
@@ -534,8 +533,30 @@ QString KlamavUpdate::getMirror()
 
     previousmirror = r;
 
-    ////kdDebug() << r << endl;
+    kdDebug() << r << endl;
     return mirrors[r];
 }
 
+double KlamavUpdate::numericizeVersion(QString &version)
+{
+        QString tmpversion = version;
+        QStringList tokens = QStringList::split(".",tmpversion);
+        for ( QStringList::Iterator it = tokens.begin(); it != tokens.end(); it++ )
+        {
+            if ((*it).length() < 2)
+                (*it).prepend("0");
+        }
+        tmpversion = tokens.join(".");
+
+        unsigned int firstdot = tmpversion.find(".");
+        for (unsigned int j=tmpversion.length(); j != firstdot; j-- ){
+            if (tmpversion.mid(j,1) == "."){
+                tmpversion.remove(j,1);
+                j--;
+            }
+        }
+
+        return tmpversion.toDouble();
+}
+
 #include "update.moc"
